@@ -9,9 +9,9 @@ Convert rates from Hartree atomic units to SI
 """
 # %% Atomic Units to SI
 Planck = 6.62607015e-34 # [J/Hz]
-'''Planck constant to Joules per Hz (energy to frequency)'''
+'Planck constant to Joules per Hz (energy to frequency)'
 redPlanck = 1.054571817e-34  # [J.s]
-'''reduced Planck constant to Joules sec (energy to time)'''
+'reduced Planck constant to Joules sec (energy to time)'
 eCharge = 1.602176634e-19 # [C]
 'elementary charge in Coulombs'
 BohrRadius = 5.29177210903e-11 # [m]
@@ -20,7 +20,10 @@ masselectron = 9.1093837015e-31 # [kg]
 'electron rest mass in kg'
 HartreeEnergy = 4.3597447222071e-18 # [J]
 'Hartree energy in Joules'
-HEeV = HartreeEnergy/1.602176634e-19
+HEeV = HartreeEnergy/1.602176634e-19 # [eV]
+'Hartree energy in eV'
+Dalton = 1.66053906660e-27 # [kg]
+'unified atomic mass unit in kilograms'
 
 # %% Derived Units to SI
 edipolemoment = eCharge*BohrRadius # [Cm]
